{"content-type": "text/plain; charset=utf-8", "content-length": "2345", "connection": "keep-alive", "date": "Tue, 24 Oct 2023 11:08:39 GMT", "x-powered-by": "huggingface-moon", "x-request-id": "Root=1-6537a5b7-75ee90ab09df1c611066e609;7a291474-324f-4645-a0ab-69392158ebbc", "access-control-allow-origin": "https://huggingface.co", "vary": "Origin", "access-control-expose-headers": "X-Repo-Commit,X-Request-Id,X-Error-Code,X-Error-Message,ETag,Link,Accept-Ranges,Content-Range", "x-repo-commit": "cfe0ba3f6d5ad4e689e77fd6b081a7df70222ba2", "accept-ranges": "bytes", "content-security-policy": "default-src none; sandbox", "etag": "\"f8fe2cb434cefda404c506d541959e2fefc86884\"", "x-cache": "Miss from cloudfront", "via": "1.1 9d2f0fb353e3a984b1bc4b73796eed40.cloudfront.net (CloudFront)", "x-amz-cf-pop": "HAN50-P2", "x-amz-cf-id": "Ao_AqHUeGKa5U4mYHx4jcFQvJaAdMLb-v6NJr3Z7umGLPLE5ahqCLQ=="}