{"content-type": "text/plain; charset=utf-8", "content-length": "5844", "connection": "keep-alive", "date": "Tue, 24 Oct 2023 11:21:17 GMT", "x-powered-by": "huggingface-moon", "x-request-id": "Root=1-6537a8ad-7daf5d854a54b4bf2d935eb1;73562070-3041-4616-8842-c658e72ec5b5", "access-control-allow-origin": "https://huggingface.co", "vary": "Origin", "access-control-expose-headers": "X-Repo-Commit,X-Request-Id,X-Error-Code,X-Error-Message,ETag,Link,Accept-Ranges,Content-Range", "x-repo-commit": "7a00892cd331d78a88c8c869d0224a5cdd149848", "accept-ranges": "bytes", "content-security-policy": "default-src none; sandbox", "etag": "\"1ab4dfa5484df579fa5fc4e1848afe9112ecf66f\"", "x-cache": "Miss from cloudfront", "via": "1.1 d9afbb25777f4a3d5e4f6ee69980e69e.cloudfront.net (CloudFront)", "x-amz-cf-pop": "HKG62-C2", "x-amz-cf-id": "VhJ1jR1J44my6nZyIT8YEFA_BSbfJnxlA9ZGVD3wPeKPoEUfBadesQ=="}