{"content-type": "text/plain; charset=utf-8", "content-length": "1924", "connection": "keep-alive", "date": "Tue, 24 Oct 2023 11:08:50 GMT", "x-powered-by": "huggingface-moon", "x-request-id": "Root=1-6537a5c2-1a8036d901b0c1546ff96865;5b2b9943-2d48-4de2-9d15-b1d7968f1987", "access-control-allow-origin": "https://huggingface.co", "vary": "Origin", "access-control-expose-headers": "X-Repo-Commit,X-Request-Id,X-Error-Code,X-Error-Message,ETag,Link,Accept-Ranges,Content-Range", "x-repo-commit": "cfe0ba3f6d5ad4e689e77fd6b081a7df70222ba2", "accept-ranges": "bytes", "content-security-policy": "default-src none; sandbox", "etag": "\"d9cee703ae23284f63078d8a15aca6d7c5614fdc\"", "x-cache": "Miss from cloudfront", "via": "1.1 b5c536696b4eaa5e71ecb973177c119a.cloudfront.net (CloudFront)", "x-amz-cf-pop": "HAN50-P2", "x-amz-cf-id": "Kb-_csqjJLSYGnru1agUzwpD4poxeqUM_9B3NmMJe24XdcrC5sgPPg=="}