{"content-type": "text/plain; charset=utf-8", "content-length": "1770", "connection": "keep-alive", "date": "Tue, 24 Oct 2023 11:28:45 GMT", "x-powered-by": "huggingface-moon", "x-request-id": "Root=1-6537aa6d-559c0323777b087b12becd84;9b0c0eb5-5301-429e-98dd-0d539b31afea", "access-control-allow-origin": "https://huggingface.co", "vary": "Origin", "access-control-expose-headers": "X-Repo-Commit,X-Request-Id,X-Error-Code,X-Error-Message,ETag,Link,Accept-Ranges,Content-Range", "x-repo-commit": "b1bcda690655777373f57ea6614eb095ec2c886f", "accept-ranges": "bytes", "content-security-policy": "default-src none; sandbox", "etag": "\"b48aaf777a3bff767ce11413fc96b10e15c8b313\"", "x-cache": "Miss from cloudfront", "via": "1.1 94db66e0b13cce35d9db0c342571f976.cloudfront.net (CloudFront)", "x-amz-cf-pop": "HKG62-C2", "x-amz-cf-id": "n6R6t2SoprBkDNNGpQKM0NhumJQ3Jx9bbZm9nJPHwvFIo2NwKtfujQ=="}