{"content-type": "text/plain; charset=utf-8", "content-length": "5666", "connection": "keep-alive", "date": "Tue, 24 Oct 2023 11:21:12 GMT", "x-powered-by": "huggingface-moon", "x-request-id": "Root=1-6537a8a8-59ed8ebb086db1b93c087c05;287be3e9-8757-4ea7-bba5-e7f354456e21", "access-control-allow-origin": "https://huggingface.co", "vary": "Origin", "access-control-expose-headers": "X-Repo-Commit,X-Request-Id,X-Error-Code,X-Error-Message,ETag,Link,Accept-Ranges,Content-Range", "x-repo-commit": "7a00892cd331d78a88c8c869d0224a5cdd149848", "accept-ranges": "bytes", "content-security-policy": "default-src none; sandbox", "etag": "\"dbc9739b9e15d692ab2cc749c1d650df087b5ba4\"", "x-cache": "Miss from cloudfront", "via": "1.1 1969b693060171ec284d3d0f19afb534.cloudfront.net (CloudFront)", "x-amz-cf-pop": "HKG62-C2", "x-amz-cf-id": "mBDdSxv-zczpQwp59iExCSX19J0PNs2a1I5Bn2hyh5K-2PwOvLiaJA=="}